@@ -18,7 +18,7 @@
 # @examples
 # format_decimal(1.5:3.5)
 # format_decimal(1e9)
-format_decimal <- function(x, sigfig, ...) {
+format_decimal <- function(x, sigfig) {
   split_decimal(x, sigfig)
 }
 
@@ -29,17 +29,20 @@ split_decimal <- function(x, sigfig, scientific = FALSE) {
   abs_x <- abs(x)
 
   num <- is.finite(x)
+  dec <- num
 
   # Do we need negative signs?
   neg <- !is.na(x) & x < 0
 
   # Compute exponent and mantissa
-  exp <- compute_exp(abs_x)
+  exp <- compute_exp(abs_x, sigfig)
 
   if (scientific) {
     # Must divide by 10^exp, because 10^-exp may not be representable
     # for very large values of exp
-    mnt <- ifelse(num & abs_x != 0, abs_x / (10^exp), abs_x)
+    mnt <- abs_x
+    mnt_idx <- which(num & abs_x != 0)
+    mnt[mnt_idx] <- abs_x[mnt_idx] / (10^exp[mnt_idx])
     round_x <- safe_signif(mnt, sigfig)
     rhs_digits <- ifelse(num & abs_x != 0, sigfig - 1, 0)
     exp_display <- exp
@@ -51,7 +54,6 @@ split_decimal <- function(x, sigfig, scientific = FALSE) {
 
   lhs <- trunc(round_x)
   rhs <- round_x - lhs
-  dec <- is.finite(x)
   if (!scientific) {
     dec[diff_to_trunc(x) == 0] <- FALSE
   }
@@ -60,7 +62,7 @@ split_decimal <- function(x, sigfig, scientific = FALSE) {
     sigfig = sigfig,
     num = num,
     neg = neg,
-    lhs = sprintf("%.0f", lhs),
+    lhs = format(lhs, scientific = FALSE, trim = TRUE),
     lhs_zero = (lhs == 0),
     rhs = rhs,
     rhs_digits = rhs_digits,
@@ -91,7 +93,7 @@ sqrt_eps <- sqrt(.Machine$double.eps)
 compute_rhs_digits <- function(x, sigfig) {
   # If already bigger than sigfig, can round to zero.
   # Otherwise ensure we have sigfig digits shown
-  exp <- compute_exp(x)
+  exp <- compute_exp(x, sigfig)
   exp[is.na(exp)] <- Inf
   rhs_digits <- rep_along(x, 0)
   if (!is.integer(x) && !all(x == trunc(x), na.rm = TRUE)) {
@@ -116,10 +118,19 @@ compute_rhs_digits <- function(x, sigfig) {
   rhs_digits
 }
 
-compute_exp <- function(x) {
+compute_exp <- function(x, sigfig) {
+  # With 3 significant digits:
+  # 0.9994 -> 0.999 -> exp == -1
+  # 0.9995 -> 1.00 -> exp == 0
+  # This means that x is divided by 0.9995 in this example
+  # before computing log10().
+  # Division before log is the same as subtraction after log.
+  # Using log1p for numerical stability.
+  offset <- log1p(-5 * 10^(-sigfig - 1)) / log(10)
+
   ret <- rep_along(x, NA_integer_)
   nonzero <- which(x != 0 & is.finite(x))
-  ret[nonzero] <- as.integer(floor(log10(x[nonzero])))
+  ret[nonzero] <- as.integer(floor(log10(x[nonzero]) - offset))
   ret
 }
 
